Interest in frequent flier program (artificial)
data("LARGEFLYER")A data frame with 100000 observations on the following 2 variables.
Gendera factor with levels Female Male
Interesta factor with levels No Yes
This artificial datasets tabulates the interest in a new frequent flyer program based on gender. It illustrates that a statistically significant association may have absolutely no practical significance.